package Weixin::Message;
use constant {
    MM_DATA_TEXT                       => 1,
    MM_DATA_HTML                       => 2,
    MM_DATA_IMG                        => 3,
    MM_DATA_PRIVATEMSG_TEXT            => 11,
    MM_DATA_PRIVATEMSG_HTML            => 12,
    MM_DATA_PRIVATEMSG_IMG             => 13,
    MM_DATA_VOICEMSG                   => 34,
    MM_DATA_PUSHMAIL                   => 35,
    MM_DATA_QMSG                       => 36,
    MM_DATA_VERIFYMSG                  => 37,
    MM_DATA_PUSHSYSTEMMSG              => 38,
    MM_DATA_QQLIXIANMSG_IMG            => 39,
    MM_DATA_POSSIBLEFRIEND_MSG         => 40,
    MM_DATA_SHARECARD                  => 42,
    MM_DATA_VIDEO                      => 43,
    MM_DATA_VIDEO_IPHONE_EXPORT        => 44,
    MM_DATA_EMOJI                      => 47,
    MM_DATA_LOCATION                   => 48,
    MM_DATA_APPMSG                     => 49,
    MM_DATA_VOIPMSG                    => 50,
    MM_DATA_STATUSNOTIFY               => 51,
    MM_DATA_VOIPNOTIFY                 => 52,
    MM_DATA_VOIPINVITE                 => 53,
    MM_DATA_MICROVIDEO                 => 62,
    MM_DATA_SYSNOTICE                  => 9999,
    MM_DATA_SYS                        => 1E4,
    MM_DATA_RECALLED                   => 10002,
    MM_DATA_READER_TYPE                => 100001,
    MM_DATA_APP_MSG_TEXT_TYPE          => 100002,
    MM_DATA_APP_MSG_IMG_TYPE           => 100003,
    MM_DATA_APP_MSG_AUDIO_TYPE         => 100004,
    MM_DATA_APP_MSG_VIDEO_TYPE         => 100005,
    MM_DATA_APP_MSG_URL_TYPE           => 100006,
    MM_DATA_APP_MSG_ATTACH_TYPE        => 100007,
    MM_DATA_APP_MSG_OPEN_TYPE          => 100008,
    MM_DATA_APP_MSG_EMOJI_TYPE         => 100009,
    MM_DATA_APPMSG_UNSUPPORT           => 65585,
    MM_MEDIA_TYPE_IMAGE                => 1,
    MM_MEDIA_TYPE_VIDEO                => 2,
    MM_MEDIA_TYPE_AUDIO                => 3,
    MM_MEDIA_TYPE_ATTACHMENT           => 4,
    SP_CONTACT_FILE_HELPER             => "filehelper",
    SP_CONTACT_NEWSAPP                 => "newsapp",
    MMWEBWX_JSLOG                      => 1,
    MMWEBWX_JSERR                      => 2,
    MMWEBWX_WEBSESSIONTIMEOUT_LOGOUT   => 4,
    MMWEBWX_CONNECT_ERR                => 5,
    MMWEBWX_USETIME                    => 6,
    MMWEBWX_LOGIN_COSTTIME             => 7,
    MMWEBWX_NEW_CHAT                   => 9,
    MMWEBWX_UPLOADMEDIA_TOO_LARGE      => 11,
    MMWEBWX_GETVOICE                   => 12,
    STATE_UNKNOWN                      => 0,
    STATE_SENDING                      => 1,
    STATE_SENT                         => 2,
    STATE_REACH                        => 3,
    STATE_READ                         => 4,
    STATE_FAILED                       => 5,
    APPMSGTYPE_TEXT                    => 1,
    APPMSGTYPE_IMG                     => 2,
    APPMSGTYPE_AUDIO                   => 3,
    APPMSGTYPE_VIDEO                   => 4,
    APPMSGTYPE_URL                     => 5,
    APPMSGTYPE_ATTACH                  => 6,
    APPMSGTYPE_OPEN                    => 7,
    APPMSGTYPE_EMOJI                   => 8,
    APPMSGTYPE_VOICE_REMIND            => 9,
    MM_APPMSG_SHOW_DEFAULT             => 0,
    MM_APPMSG_SHOW_READER              => 1,
    MM_APPMSG_SHAKETRANIMG_RESULT      => 2,
    MM_APPMSG_VOICEREMIND_CONFIRM      => 3,
    MM_APPMSG_VOICEREMIND_REMIND       => 4,
    MM_APPMSG_VOICEREMIND_SYS          => 5,
    MM_BIZ_DATA_TEXT                   => 1,
    MM_BIZ_DATA_IMG                    => 2,
    MM_BIZ_DATA_VOICE                  => 3,
    MM_BIZ_DATA_VIDEO                  => 4,
    MM_BIZ_DATA_APPMSG                 => 10,
    MM_BIZ_DATA_SHARECARD              => 42,
    MM_CONTACTFLAG_CONTACT             => 1,
    MM_CONTACTFLAG_CHATCONTACT         => 2,
    MM_CONTACTFLAG_CHATROOMCONTACT     => 4,
    MM_CONTACTFLAG_BLACKLISTCONTACT    => 8,
    MM_CONTACTFLAG_DOMAINCONTACT       => 16,
    MM_CONTACTFLAG_HIDECONTACT         => 32,
    MM_CONTACTFLAG_FAVOURCONTACT       => 64,
    MM_CONTACTFLAG_3RDAPPCONTACT       => 128,
    MM_CONTACTFLAG_SNSBLACKLISTCONTACT => 256,
    MM_CONTACTFLAG_NOTIFYCLOSECONTACT  => 512,
    MM_USERATTRVERIFYFALG_BIZ          => 1,
    MM_USERATTRVERIFYFALG_FAMOUS       => 2,
    MM_USERATTRVERIFYFALG_BIZ_BIG      => 4,
    MM_USERATTRVERIFYFALG_BIZ_BRAND    => 8,
    MM_USERATTRVERIFYFALG_BIZ_VERIFIED => 16,
    StatusNotifyCode_READED            => 1,
    StatusNotifyCode_ENTER_SESSION     => 2,
    StatusNotifyCode_INITED            => 3,
    StatusNotifyCode_SYNC_CONV         => 4,
    StatusNotifyCode_QUIT_SESSION      => 5,
    MM_WEBWXFUNCTION_TONE_NOT_OPEN     => 1,
    MM_WEBWXFUNCTION_NOTIFY_OPEN       => 2,
    MM_VERIFYUSER_ADDCONTACT           => 1,
    MM_VERIFYUSER_SENDREQUEST          => 2,
    MM_VERIFYUSER_VERIFYOK             => 3,
    MM_VERIFYUSER_VERIFYREJECT         => 4,
    MM_VERIFYUSER_SENDERREPLY          => 5,
    MM_VERIFYUSER_RECVERREPLY          => 6,
    MM_ADDSCENE_PF_QQ                  => 4,
    MM_ADDSCENE_PF_EMAIL               => 5,
    MM_ADDSCENE_PF_CONTACT             => 6,
    MM_ADDSCENE_PF_WEIXIN              => 7,
    MM_ADDSCENE_PF_GROUP               => 8,
    MM_ADDSCENE_PF_UNKNOWN             => 9,
    MM_ADDSCENE_PF_MOBILE              => 10,
    EN_INFORMAT_NULL                   => 0,
    EN_INFORMAT_AMR                    => 1,
    EN_INFORMAT_MP3                    => 2,
    EN_INFORMAT_MP4                    => 3,
    EN_INFORMAT_WMA                    => 4,
    EN_INFORMAT_WAV                    => 5,
    EN_INFORMAT_WMV                    => 6,
    EN_INFORMAT_ASF                    => 7,
    EN_INFORMAT_RM                     => 8,
    EN_INFORMAT_RMVB                   => 9,
    EN_INFORMAT_AVI                    => 10,
    EN_INFORMAT_MPG                    => 11,
    EN_INFORMAT_MPEG                   => 12,
    EN_INFORMAT_BUTT                   => 13,
    MM_STATUS_VERIFY_USER              => 32,
    MMWEBWX_OPLOG_BLACKCONTACT         => 1,
    MMWEBWX_OPLOG_MODREMARKNAME        => 2,
    MMWEBWX_OPLOG_BLACKCONTACT_DELETE  => 0,
    MMWEBWX_OPLOG_BLACKCONTACT_ADD     => 1,
    MM_CHATROOM_NOTIFY_OPEN            => 1,
    MM_CHATROOM_NOTIFY_CLOSE           => 0,
    MM_MEMBER_OK                       => 0,
    MM_MEMBER_NOUSER                   => 1,
    MM_MEMBER_USERNAMEINVALID          => 2,
    MM_MEMBER_BLACKLIST                => 3,
    MM_MEMBER_NEEDVERIFYUSER           => 4,
    MM_MEMBER_UNSUPPORT_TALK           => 5,
};
1;
